darkhistory.electrons.positronium — DarkHistory documentation

# darkhistory.electrons.positronium

Positronium annihilation functions.

Functions

`ortho_photon_spec`(eng) | Returns the photon spectrum from orthopositronium annihilation.
`para_photon_spec`(eng) | Returns the photon spectrum from parapositronium annihilation.
`weighted_photon_spec`(eng) | Returns the weighted photon spectrum from positronium annihilation.

#### Previous topic

darkhistory.electrons.elec_cooling.get_elec_cooling_tf

#### Next topic

darkhistory.electrons.positronium.ortho_photon_spec

### This Page

Show Source